@@ -6,7 +6,7 @@
 #ifndef _IP_VS_H
 #define _IP_VS_H
 
-#define IP_VS_VERSION_CODE            0x000201
+#define IP_VS_VERSION_CODE            0x000202
 #define NVERSION(version)                       \
         (version >> 16) & 0xFF,                 \
         (version >> 8) & 0xFF,                  \
@@ -95,6 +95,7 @@ struct ip_vs_rule_user {
 #define IP_VS_CONN_F_IN_SEQ           0x0400    /* must do input seq adjust */
 #define IP_VS_CONN_F_NO_CPORT         0x0800    /* no client port set yet */
 
+#define NFMARK_IPVS_PROPERTY	      -0x100
 
 #ifdef __KERNEL__
 
@@ -367,6 +368,8 @@ extern struct ip_vs_conn * ip_vs_schedule(struct ip_vs_service *svc,
                                           struct iphdr *iph);
 extern int ip_vs_proto_doff(unsigned proto, char *th, unsigned size);
 extern const char *ip_vs_proto_name(unsigned proto);
+extern unsigned int check_for_ip_vs_out(struct sk_buff **skb_p,
+                                        int (*okfn)(struct sk_buff *));
 
 
 /*
