@@ -1,7 +1,7 @@
 /*
  * IPVS         Application module
  *
- * Version:     $Id: ip_vs_app.c,v 1.4 2000/09/06 08:36:36 wensong Exp $
+ * Version:     $Id: ip_vs_app.c,v 1.6 2001/01/10 07:42:53 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *
@@ -16,7 +16,7 @@
  *
  *		IP_MASQ_APP application masquerading module
  *
- * 	$Id: ip_vs_app.c,v 1.4 2000/09/06 08:36:36 wensong Exp $
+ * 	$Id: ip_vs_app.c,v 1.6 2001/01/10 07:42:53 wensong Exp $
  *
  * Author:	Juan Jose Ciarlante, <jjciarla@raiz.uncu.edu.ar>
  *
@@ -238,11 +238,11 @@ static inline void vs_fix_seq(const struct ip_vs_seq *vseq, struct tcphdr *th)
         if (vseq->delta || vseq->previous_delta) {
                 if(after(seq, vseq->init_seq)) {
                         th->seq = htonl(seq + vseq->delta);
-                        IP_VS_DBG(1, "vs_fix_seq(): added delta (%d) to seq\n",
+                        IP_VS_DBG(9, "vs_fix_seq(): added delta (%d) to seq\n",
                                   vseq->delta);
                 } else {
                         th->seq = htonl(seq + vseq->previous_delta);
-                        IP_VS_DBG(1, "vs_fix_seq(): added previous_delta "
+                        IP_VS_DBG(9, "vs_fix_seq(): added previous_delta "
                                   "(%d) to seq\n", vseq->previous_delta);
                 }
         }
@@ -265,12 +265,12 @@ vs_fix_ack_seq(const struct ip_vs_seq *vseq, struct tcphdr *th)
         if (vseq->delta || vseq->previous_delta) {
                 if(after(ack_seq, vseq->init_seq)) {
                         th->ack_seq = htonl(ack_seq - vseq->delta);
-                        IP_VS_DBG(1, "vs_fix_ack_seq(): subtracted delta "
+                        IP_VS_DBG(9, "vs_fix_ack_seq(): subtracted delta "
                                   "(%d) from ack_seq\n", vseq->delta);
 
                 } else {
                         th->ack_seq = htonl(ack_seq - vseq->previous_delta);
-                        IP_VS_DBG(1, "vs_fix_ack_seq(): subtracted "
+                        IP_VS_DBG(9, "vs_fix_ack_seq(): subtracted "
                                   "previous_delta (%d) from ack_seq\n",
                                   vseq->previous_delta);
                 }
@@ -430,7 +430,7 @@ static int ip_vs_app_getinfo(char *buffer, char **start, off_t offset,
                         vapp = list_entry(e, struct ip_vs_app, n_list);
 
                         size += sprintf(buffer+len, "%-3s  %-7u %-6d %-17s\n",
-                                        vs_proto_name(
+                                        ip_vs_proto_name(
                                                 IP_VS_APP_PROTO(vapp->type)),
                                         IP_VS_APP_PORT(vapp->type),
                                         GET_USE_COUNT(vapp->module),
@@ -546,7 +546,7 @@ struct sk_buff *ip_vs_skb_replace(struct sk_buff *skb, int pri, char *o_buf,
         struct sk_buff *n_skb;
         unsigned skb_len;
 
-	EnterFunction(4);
+	EnterFunction(9);
 
         diff = n_len - o_len;
         n_skb = skb_replace(skb, pri, o_buf, o_len, n_buf, n_len);
@@ -555,7 +555,7 @@ struct sk_buff *ip_vs_skb_replace(struct sk_buff *skb, int pri, char *o_buf,
         if (diff)
         {
                 struct iphdr *iph;
-                IP_VS_DBG(1, "pkt resized for %d bytes (len=%d)\n",
+                IP_VS_DBG(9, "pkt resized for %d bytes (len=%d)\n",
                           diff, skb->len);
                 /*
                  * 	update ip header
@@ -566,7 +566,7 @@ struct sk_buff *ip_vs_skb_replace(struct sk_buff *skb, int pri, char *o_buf,
                 iph->check = ip_fast_csum((unsigned char *)iph, iph->ihl);
         }
         
-        LeaveFunction(4);
+        LeaveFunction(9);
         return n_skb;
 }
 
