@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.11 2001/01/10 07:42:53 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.12 2001/01/26 10:19:23 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -64,6 +64,7 @@ EXPORT_SYMBOL(ip_vs_conn_put);
 #ifdef CONFIG_IP_VS_DEBUG
 EXPORT_SYMBOL(ip_vs_get_debug_level);
 #endif
+EXPORT_SYMBOL(check_for_ip_vs_out);
 
 
 /* ID used in ICMP lookups */
@@ -499,6 +500,23 @@ static int ip_vs_leave(struct ip_vs_service *svc, struct sk_buff *skb)
 }
 
 
+static unsigned int ip_vs_post_routing(unsigned int hooknum,
+                                       struct sk_buff **skb_p,
+                                       const struct net_device *in,
+                                       const struct net_device *out,
+                                       int (*okfn)(struct sk_buff *))
+{
+        struct sk_buff  *skb = *skb_p;
+
+	if (skb->nfmark != NFMARK_IPVS_PROPERTY)
+                return NF_ACCEPT;
+
+	/* The packet was sent from IPVS, exit this chain */
+        (*okfn)(skb);
+        
+	return NF_STOLEN;
+}
+
 /*
  *	Handle ICMP messages in the inside-to-outside direction (outgoing).
  *	Find any that might be relevant, check against existing connections,
@@ -594,6 +612,8 @@ static int ip_vs_out_icmp(struct sk_buff **skb_p)
 		  NIPQUAD(ciph->saddr), ntohs(pptr[0]),
 		  NIPQUAD(ciph->daddr), ntohs(pptr[1]));
 
+	skb->nfmark = NFMARK_IPVS_PROPERTY;
+
 	return NF_ACCEPT;
 }
 
@@ -610,22 +630,20 @@ static unsigned int ip_vs_out(unsigned int hooknum,
                               int (*okfn)(struct sk_buff *))
 {
 	struct sk_buff  *skb = *skb_p;
-	struct iphdr	*iph = skb->nh.iph;
+	struct iphdr	*iph;
 	union ip_vs_tphdr h;
 	struct ip_vs_conn *cp;
 	int size;
-
-	/*
-	 * 	doff holds transport protocol data offset
-	 *	csum holds its checksum
-	 *	csum_ok says if csum is valid
-	 */
-	int doff = 0;
-	int csum = 0;
-	int csum_ok = 0;
+        int doff;                       /* transport protocol data offset */
+        int csum;                       /* checksum */
+        int csum_ok;                    /* csum_ok says if csum is valid */
 
 	EnterFunction(11);
 
+	if (skb->nfmark == NFMARK_IPVS_PROPERTY)
+                return NF_ACCEPT;
+
+	iph = skb->nh.iph;
 	h.raw = (char*) iph + iph->ihl * 4;
 	size = ntohs(iph->tot_len) - (iph->ihl * 4);
 	doff = ip_vs_proto_doff(iph->protocol, h.raw, size);
@@ -676,6 +694,8 @@ static unsigned int ip_vs_out(unsigned int hooknum,
         }
 
         /* Check if the checksum is OK, when it is not UDP or check!=0 */
+	csum = 0;
+	csum_ok = 0;
         if ((iph->protocol != IPPROTO_UDP) || (h.uh->check != 0)) {
                 switch (skb->ip_summed)
                 {
@@ -684,6 +704,7 @@ static unsigned int ip_vs_out(unsigned int hooknum,
                         IP_VS_DBG(11, "O-pkt: %s I-datacsum=%d\n",
                                   ip_vs_proto_name(iph->protocol), csum);
                         skb->csum = csum_partial(h.raw , doff, csum);
+                        csum_ok++;
                         break;
 
                 case CHECKSUM_HW:
@@ -741,10 +762,8 @@ static unsigned int ip_vs_out(unsigned int hooknum,
  	/*
  	 *	Adjust packet accordingly to protocol
  	 */
-	/*
-	 *	Transport's payload partial csum
-	 */
 	if (!csum_ok) {
+                /* transport's payload partial csum */
 		csum = csum_partial(h.raw + doff, size - doff, 0);
 	}
 	skb->csum = csum;
@@ -782,11 +801,31 @@ static unsigned int ip_vs_out(unsigned int hooknum,
 	ip_vs_set_state(cp, VS_STATE_OUTPUT, iph, h.portp);
 	ip_vs_conn_put(cp);
         
+	skb->nfmark = NFMARK_IPVS_PROPERTY;
+
         LeaveFunction(11);
 	return NF_ACCEPT;
 }
 
 
+unsigned int check_for_ip_vs_out(struct sk_buff **skb_p,
+                                 int (*okfn)(struct sk_buff *))
+{
+        unsigned int ret;
+        
+        ret = ip_vs_out(NF_IP_FORWARD, skb_p, NULL, NULL, NULL);
+        if (ret != NF_ACCEPT) {
+                return ret;
+        } else {
+                if ((*skb_p)->nfmark == NFMARK_IPVS_PROPERTY) {
+                        (*okfn)(*skb_p);
+                        return NF_STOLEN;
+                }
+        }
+        return NF_ACCEPT;
+}
+
+        
 /*
  *	Handle ICMP messages in the outside-to-inside direction (incoming).
  *	Find any that might be relevant, check against existing connections,
@@ -959,7 +998,7 @@ static unsigned int ip_vs_in(unsigned int hooknum,
 	union ip_vs_tphdr h;
 	struct ip_vs_conn *cp;
 	unsigned short size;
-	int doff = 0;
+	int doff;
 	struct ip_vs_service *svc;
 
 	/*
@@ -1075,13 +1114,19 @@ static unsigned int ip_vs_in(unsigned int hooknum,
    applied to IPVS. */
 static struct nf_hook_ops ip_vs_in_ops = {
         { NULL, NULL },
-        ip_vs_in, PF_INET, /* NF_IP_PRE_ROUTING */NF_IP_LOCAL_IN, 100
+        ip_vs_in, PF_INET, NF_IP_LOCAL_IN, 100
 };
 
 /* After packet filtering, change source only for VS/NAT */
 static struct nf_hook_ops ip_vs_out_ops = {
         { NULL, NULL },
-        ip_vs_out, PF_INET, /* NF_IP_POST_ROUTING */NF_IP_FORWARD, 100
+        ip_vs_out, PF_INET, NF_IP_FORWARD, 100
+};
+
+/* Before the netfilter connection tracking, exit from POST_ROUTING */
+static struct nf_hook_ops ip_vs_post_routing_ops = {
+        { NULL, NULL },
+        ip_vs_post_routing, PF_INET, NF_IP_POST_ROUTING, NF_IP_PRI_NAT_SRC-1
 };
 
 
@@ -1122,10 +1167,17 @@ static int __init ip_vs_init(void)
 		IP_VS_ERR("can't register out hook.\n");
 		goto cleanup_inops;
 	}
+	ret = nf_register_hook(&ip_vs_post_routing_ops);
+	if (ret < 0) {
+		IP_VS_ERR("can't register post_routing hook.\n");
+		goto cleanup_outops;
+	}
 
         IP_VS_INFO("ipvs loaded.\n");
 	return ret;
 
+  cleanup_outops:
+	nf_unregister_hook(&ip_vs_out_ops);
   cleanup_inops:
 	nf_unregister_hook(&ip_vs_in_ops);
   cleanup_app:
@@ -1141,6 +1193,7 @@ static int __init ip_vs_init(void)
 
 static void __exit ip_vs_cleanup(void)
 {
+	nf_unregister_hook(&ip_vs_post_routing_ops);
 	nf_unregister_hook(&ip_vs_out_ops);
 	nf_unregister_hook(&ip_vs_in_ops);
 	ip_vs_app_cleanup();
